nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Ctrl

Struct Ctrl 

#[repr(transparent)]
pub struct Ctrl(pub u32);
USB PHY General Control Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl

pub const fn enhostdiscondetect(&self) -> bool

For host mode, enables high-speed disconnect detector

pub const fn set_enhostdiscondetect(&mut self, val: bool)

For host mode, enables high-speed disconnect detector

pub const fn hostdiscondetect_irq(&self) -> bool

Indicates that the device has disconnected in High-Speed mode

pub const fn set_hostdiscondetect_irq(&mut self, val: bool)

Indicates that the device has disconnected in High-Speed mode

pub const fn endevplugindet(&self) -> CtrlEndevplugindet

Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode

pub const fn set_endevplugindet(&mut self, val: CtrlEndevplugindet)

Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode

pub const fn devplugin_irq(&self) -> bool

Indicates that the device is connected

pub const fn set_devplugin_irq(&mut self, val: bool)

Indicates that the device is connected

pub const fn enutmilevel2(&self) -> bool

Enables UTMI+ Level 2 operation for the USB HS PHY

pub const fn set_enutmilevel2(&mut self, val: bool)

Enables UTMI+ Level 2 operation for the USB HS PHY

pub const fn enutmilevel3(&self) -> bool

Enables UTMI+ Level 3 operation for the USB HS PHY

pub const fn set_enutmilevel3(&mut self, val: bool)

Enables UTMI+ Level 3 operation for the USB HS PHY

pub const fn autoresume_en(&self) -> bool

Enable the auto resume feature, when set, HW will use 32KHz clock to send Resume to respond to the device remote wakeup(for host mode only)

pub const fn set_autoresume_en(&mut self, val: bool)

Enable the auto resume feature, when set, HW will use 32KHz clock to send Resume to respond to the device remote wakeup(for host mode only)

pub const fn enautoclr_clkgate(&self) -> bool

Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended

pub const fn set_enautoclr_clkgate(&mut self, val: bool)

Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended

pub const fn enautoclr_phy_pwd(&self) -> bool

Enables the feature to auto-clear the PWD register bits in PWD if there is wakeup event while USB is suspended

pub const fn set_enautoclr_phy_pwd(&mut self, val: bool)

Enables the feature to auto-clear the PWD register bits in PWD if there is wakeup event while USB is suspended

pub const fn fsdll_rst_en(&self) -> bool

Enables the feature to reset the FSDLL lock detection logic at the end of each TX packet.

pub const fn set_fsdll_rst_en(&mut self, val: bool)

Enables the feature to reset the FSDLL lock detection logic at the end of each TX packet.

pub const fn host_force_ls_se0(&self) -> bool

Forces the next FS packet that is transmitted to have a EOP with low-speed timing

pub const fn set_host_force_ls_se0(&mut self, val: bool)

Forces the next FS packet that is transmitted to have a EOP with low-speed timing

pub const fn utmi_suspendm(&self) -> bool

Used by the PHY to indicate a powered-down state

pub const fn set_utmi_suspendm(&mut self, val: bool)

Used by the PHY to indicate a powered-down state

pub const fn clkgate(&self) -> bool

Gate UTMI Clocks

pub const fn set_clkgate(&mut self, val: bool)

Gate UTMI Clocks

pub const fn sftrst(&self) -> bool

Writing a 1 to this bit will soft-reset the PWD, TX, RX, and CTRL registers

pub const fn set_sftrst(&mut self, val: bool)

Writing a 1 to this bit will soft-reset the PWD, TX, RX, and CTRL registers