#[repr(transparent)]pub struct Pwd(pub u32);Expand description
USB PHY Power-Down Register
Tuple Fields
0: u32Implementations
Sourceimpl Pwd
impl Pwd
Sourcepub const fn txpwdfs(&self) -> PwdTxpwdfs
pub const fn txpwdfs(&self) -> PwdTxpwdfs
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdfs(&mut self, val: PwdTxpwdfs)
pub const fn set_txpwdfs(&mut self, val: PwdTxpwdfs)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdibias(&self) -> PwdTxpwdibias
pub const fn txpwdibias(&self) -> PwdTxpwdibias
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdibias(&mut self, val: PwdTxpwdibias)
pub const fn set_txpwdibias(&mut self, val: PwdTxpwdibias)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdv2i(&self) -> PwdTxpwdv2i
pub const fn txpwdv2i(&self) -> PwdTxpwdv2i
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdv2i(&mut self, val: PwdTxpwdv2i)
pub const fn set_txpwdv2i(&mut self, val: PwdTxpwdv2i)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdenv(&self) -> PwdRxpwdenv
pub const fn rxpwdenv(&self) -> PwdRxpwdenv
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdenv(&mut self, val: PwdRxpwdenv)
pub const fn set_rxpwdenv(&mut self, val: PwdRxpwdenv)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwd1pt1(&self) -> PwdRxpwd1pt1
pub const fn rxpwd1pt1(&self) -> PwdRxpwd1pt1
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwd1pt1(&mut self, val: PwdRxpwd1pt1)
pub const fn set_rxpwd1pt1(&mut self, val: PwdRxpwd1pt1)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwddiff(&self) -> PwdRxpwddiff
pub const fn rxpwddiff(&self) -> PwdRxpwddiff
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwddiff(&mut self, val: PwdRxpwddiff)
pub const fn set_rxpwddiff(&mut self, val: PwdRxpwddiff)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdrx(&self) -> PwdRxpwdrx
pub const fn rxpwdrx(&self) -> PwdRxpwdrx
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdrx(&mut self, val: PwdRxpwdrx)
pub const fn set_rxpwdrx(&mut self, val: PwdRxpwdrx)
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled