#[repr(transparent)]pub struct RxClr(pub u32);Expand description
USB PHY Receiver Control Register
Tuple Fields
0: u32Implementations
Sourceimpl RxClr
impl RxClr
Sourcepub const fn envadj(&self) -> RxClrEnvadj
pub const fn envadj(&self) -> RxClrEnvadj
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn set_envadj(&mut self, val: RxClrEnvadj)
pub const fn set_envadj(&mut self, val: RxClrEnvadj)
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn disconadj(&self) -> RxClrDisconadj
pub const fn disconadj(&self) -> RxClrDisconadj
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn set_disconadj(&mut self, val: RxClrDisconadj)
pub const fn set_disconadj(&mut self, val: RxClrDisconadj)
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn rxdbypass(&self) -> RxClrRxdbypass
pub const fn rxdbypass(&self) -> RxClrRxdbypass
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver
Sourcepub const fn set_rxdbypass(&mut self, val: RxClrRxdbypass)
pub const fn set_rxdbypass(&mut self, val: RxClrRxdbypass)
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver