#[repr(transparent)]pub struct RxTog(pub u32);Expand description
USB PHY Receiver Control Register
Tuple Fields
0: u32Implementations
Sourceimpl RxTog
impl RxTog
Sourcepub const fn envadj(&self) -> RxTogEnvadj
pub const fn envadj(&self) -> RxTogEnvadj
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn set_envadj(&mut self, val: RxTogEnvadj)
pub const fn set_envadj(&mut self, val: RxTogEnvadj)
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn disconadj(&self) -> RxTogDisconadj
pub const fn disconadj(&self) -> RxTogDisconadj
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn set_disconadj(&mut self, val: RxTogDisconadj)
pub const fn set_disconadj(&mut self, val: RxTogDisconadj)
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn rxdbypass(&self) -> RxTogRxdbypass
pub const fn rxdbypass(&self) -> RxTogRxdbypass
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver
Sourcepub const fn set_rxdbypass(&mut self, val: RxTogRxdbypass)
pub const fn set_rxdbypass(&mut self, val: RxTogRxdbypass)
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver