#[repr(transparent)]pub struct Status(pub u32);Expand description
USB PHY Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Status
impl Status
Sourcepub const fn hostdiscondetect_status(&self) -> HostdiscondetectStatus
pub const fn hostdiscondetect_status(&self) -> HostdiscondetectStatus
Indicates at the local host (downstream) port that the remote device has disconnected while in High-Speed mode
Sourcepub const fn set_hostdiscondetect_status(&mut self, val: HostdiscondetectStatus)
pub const fn set_hostdiscondetect_status(&mut self, val: HostdiscondetectStatus)
Indicates at the local host (downstream) port that the remote device has disconnected while in High-Speed mode
Sourcepub const fn devplugin_status(&self) -> DevpluginStatus
pub const fn devplugin_status(&self) -> DevpluginStatus
Status indicator for non-standard resistive plugged-in detection Indicates that the device has been connected on the USB_DP and USB_DM lines using the nonstandard resistive plugged-in detection method controlled by CTRL[4]
Sourcepub const fn set_devplugin_status(&mut self, val: DevpluginStatus)
pub const fn set_devplugin_status(&mut self, val: DevpluginStatus)
Status indicator for non-standard resistive plugged-in detection Indicates that the device has been connected on the USB_DP and USB_DM lines using the nonstandard resistive plugged-in detection method controlled by CTRL[4]
Sourcepub const fn resume_status(&self) -> bool
pub const fn resume_status(&self) -> bool
Indicates that the host is sending a wake-up after Suspend and has triggered an interrupt.
Sourcepub const fn set_resume_status(&mut self, val: bool)
pub const fn set_resume_status(&mut self, val: bool)
Indicates that the host is sending a wake-up after Suspend and has triggered an interrupt.