nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

TrimOverrideEnClr

Struct TrimOverrideEnClr 

#[repr(transparent)]
pub struct TrimOverrideEnClr(pub u32);
USB PHY Trim Override Enable Register

Tuple Fields

0: u32

Implementations

Source

impl TrimOverrideEnClr

pub const fn trim_div_sel_override(&self) -> bool

Override enable for PLL_DIV_SEL, when set, the register value in PLL_SIC[1:0] will be used.

pub const fn set_trim_div_sel_override(&mut self, val: bool)

Override enable for PLL_DIV_SEL, when set, the register value in PLL_SIC[1:0] will be used.

pub const fn trim_env_tail_adj_vd_override(&self) -> bool

Override enable for ENV_TAIL_ADJ, when set, the register value in DEBUG1[14:13] will be used.

pub const fn set_trim_env_tail_adj_vd_override(&mut self, val: bool)

Override enable for ENV_TAIL_ADJ, when set, the register value in DEBUG1[14:13] will be used.

pub const fn trim_tx_d_cal_override(&self) -> bool

Override enable for TX_D_CAL, when set, the register value in TX[3:0] will be used.

pub const fn set_trim_tx_d_cal_override(&mut self, val: bool)

Override enable for TX_D_CAL, when set, the register value in TX[3:0] will be used.

pub const fn trim_tx_cal45dp_override(&self) -> bool

Override enable for TX_CAL45DP, when set, the register value in TX[19:16] will be used.

pub const fn set_trim_tx_cal45dp_override(&mut self, val: bool)

Override enable for TX_CAL45DP, when set, the register value in TX[19:16] will be used.

pub const fn trim_tx_cal45dm_override(&self) -> bool

Override enable for TX_CAL45DM, when set, the register value in TX[11:8] will be used.

pub const fn set_trim_tx_cal45dm_override(&mut self, val: bool)

Override enable for TX_CAL45DM, when set, the register value in TX[11:8] will be used.

pub const fn trim_refbias_vbgadj_override(&self) -> bool

Override enable for bandgap adjustment

pub const fn set_trim_refbias_vbgadj_override(&mut self, val: bool)

Override enable for bandgap adjustment

pub const fn trim_refbias_tst_override(&self) -> bool

Override enable for bias current control When this field is set, the register value in DEBUG1[22:21] will be used

pub const fn set_trim_refbias_tst_override(&mut self, val: bool)

Override enable for bias current control When this field is set, the register value in DEBUG1[22:21] will be used

pub const fn trim_usb2_refbias_vbgadj(&self) -> u8

Adjustment bits for bandgap

pub const fn set_trim_usb2_refbias_vbgadj(&mut self, val: u8)

Adjustment bits for bandgap

pub const fn trim_usb2_refbias_tst(&self) -> u8

Bias current control for usb2_phy

pub const fn set_trim_usb2_refbias_tst(&mut self, val: u8)

Bias current control for usb2_phy

pub const fn trim_pll_ctrl0_div_sel(&self) -> u8

IFR value of PLL_DIV_SEL.

pub const fn set_trim_pll_ctrl0_div_sel(&mut self, val: u8)

IFR value of PLL_DIV_SEL.

pub const fn trim_usb_reg_env_tail_adj_vd(&self) -> u8

IFR value of ENV_TAIL_ADJ.

pub const fn set_trim_usb_reg_env_tail_adj_vd(&mut self, val: u8)

IFR value of ENV_TAIL_ADJ.

pub const fn trim_usbphy_tx_d_cal(&self) -> u8

IFR value of TX_D_CAL.

pub const fn set_trim_usbphy_tx_d_cal(&mut self, val: u8)

IFR value of TX_D_CAL.

pub const fn trim_usbphy_tx_cal45dp(&self) -> u8

IFR value of TX_CAL45DP.

pub const fn set_trim_usbphy_tx_cal45dp(&mut self, val: u8)

IFR value of TX_CAL45DP.

pub const fn trim_usbphy_tx_cal45dm(&self) -> u8

IFR value of TX_CAL45DM.

pub const fn set_trim_usbphy_tx_cal45dm(&mut self, val: u8)

IFR value of TX_CAL45DM.