nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usb1ChrgDetStat

Struct Usb1ChrgDetStat 

#[repr(transparent)]
pub struct Usb1ChrgDetStat(pub u32);
USB PHY Charger Detect Status Register

Tuple Fields

0: u32

Implementations

Source

impl Usb1ChrgDetStat

pub const fn plug_contact(&self) -> PlugContact

Battery Charging Data Contact Detection phase output During the Data Contact Detection phase per the USB Battery Charging Specification Revision 1

pub const fn set_plug_contact(&mut self, val: PlugContact)

Battery Charging Data Contact Detection phase output During the Data Contact Detection phase per the USB Battery Charging Specification Revision 1

pub const fn chrg_detected(&self) -> ChrgDetected

Battery Charging Primary Detection phase output During the USB Battery Charging Primary Detection phase using the USBHSDCD module, this bit field indicates whether a Standard Downstream Port or Charging Port was detected

pub const fn set_chrg_detected(&mut self, val: ChrgDetected)

Battery Charging Primary Detection phase output During the USB Battery Charging Primary Detection phase using the USBHSDCD module, this bit field indicates whether a Standard Downstream Port or Charging Port was detected

pub const fn dm_state(&self) -> DmState

Single ended receiver output for the USB_DM pin, from charger detection circuits.

pub const fn set_dm_state(&mut self, val: DmState)

Single ended receiver output for the USB_DM pin, from charger detection circuits.

pub const fn dp_state(&self) -> DpState

Single ended receiver output for the USB_DP pin, from charger detection circuits.

pub const fn set_dp_state(&mut self, val: DpState)

Single ended receiver output for the USB_DP pin, from charger detection circuits.

pub const fn secdet_dcp(&self) -> SecdetDcp

Battery Charging Secondary Detection phase output During the USB Battery Charging Secondary Detection phase using the USBHSDCD module, this bit field indicates which kind of Charging Port was detected

pub const fn set_secdet_dcp(&mut self, val: SecdetDcp)

Battery Charging Secondary Detection phase output During the USB Battery Charging Secondary Detection phase using the USBHSDCD module, this bit field indicates which kind of Charging Port was detected