#[repr(transparent)]pub struct Usb1ChrgDetectSet(pub u32);Expand description
USB PHY Charger Detect Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1ChrgDetectSet
impl Usb1ChrgDetectSet
Sourcepub const fn pullup_dp(&self) -> bool
pub const fn pullup_dp(&self) -> bool
This bit is used to pull up DP, for digital charge detect.
Sourcepub const fn set_pullup_dp(&mut self, val: bool)
pub const fn set_pullup_dp(&mut self, val: bool)
This bit is used to pull up DP, for digital charge detect.
Sourcepub const fn bgr_ibias(&self) -> Usb1ChrgDetectSetBgrIbias
pub const fn bgr_ibias(&self) -> Usb1ChrgDetectSetBgrIbias
USB charge detector bias current reference This bit determines the reference for the bias current of the USB charge detector
Sourcepub const fn set_bgr_ibias(&mut self, val: Usb1ChrgDetectSetBgrIbias)
pub const fn set_bgr_ibias(&mut self, val: Usb1ChrgDetectSetBgrIbias)
USB charge detector bias current reference This bit determines the reference for the bias current of the USB charge detector