#[repr(transparent)]pub struct Usb1LoopbackTog(pub u32);Expand description
USB PHY Loopback Control/Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1LoopbackTog
impl Usb1LoopbackTog
Sourcepub const fn utmi_teststart(&self) -> bool
pub const fn utmi_teststart(&self) -> bool
This bit enables the USB loopback test.
Sourcepub const fn set_utmi_teststart(&mut self, val: bool)
pub const fn set_utmi_teststart(&mut self, val: bool)
This bit enables the USB loopback test.
Sourcepub const fn utmi_dig_tst0(&self) -> bool
pub const fn utmi_dig_tst0(&self) -> bool
Mode control for USB loopback test
Sourcepub const fn set_utmi_dig_tst0(&mut self, val: bool)
pub const fn set_utmi_dig_tst0(&mut self, val: bool)
Mode control for USB loopback test
Sourcepub const fn utmi_dig_tst1(&self) -> bool
pub const fn utmi_dig_tst1(&self) -> bool
Mode control for USB loopback test
Sourcepub const fn set_utmi_dig_tst1(&mut self, val: bool)
pub const fn set_utmi_dig_tst1(&mut self, val: bool)
Mode control for USB loopback test
Sourcepub const fn tsti_tx_hs_mode(&self) -> bool
pub const fn tsti_tx_hs_mode(&self) -> bool
Select HS or FS mode for USB loopback testing
Sourcepub const fn set_tsti_tx_hs_mode(&mut self, val: bool)
pub const fn set_tsti_tx_hs_mode(&mut self, val: bool)
Select HS or FS mode for USB loopback testing
Sourcepub const fn tsti_tx_ls_mode(&self) -> bool
pub const fn tsti_tx_ls_mode(&self) -> bool
Set to value 1’b1 to choose LS for USB loopback testing, set to value 1’b0 to choose HS or FS mode which is defined by TSTI1_TX_HS
Sourcepub const fn set_tsti_tx_ls_mode(&mut self, val: bool)
pub const fn set_tsti_tx_ls_mode(&mut self, val: bool)
Set to value 1’b1 to choose LS for USB loopback testing, set to value 1’b0 to choose HS or FS mode which is defined by TSTI1_TX_HS
Sourcepub const fn tsti_tx_en(&self) -> bool
pub const fn tsti_tx_en(&self) -> bool
Enable TX for USB loopback test.
Sourcepub const fn set_tsti_tx_en(&mut self, val: bool)
pub const fn set_tsti_tx_en(&mut self, val: bool)
Enable TX for USB loopback test.
Sourcepub const fn tsti_tx_hiz(&self) -> bool
pub const fn tsti_tx_hiz(&self) -> bool
Sets TX Hi-Z for USB loopback test.
Sourcepub const fn set_tsti_tx_hiz(&mut self, val: bool)
pub const fn set_tsti_tx_hiz(&mut self, val: bool)
Sets TX Hi-Z for USB loopback test.
Sourcepub const fn utmo_dig_tst0(&self) -> bool
pub const fn utmo_dig_tst0(&self) -> bool
This read-only bit is a status bit for USB loopback test results
Sourcepub const fn set_utmo_dig_tst0(&mut self, val: bool)
pub const fn set_utmo_dig_tst0(&mut self, val: bool)
This read-only bit is a status bit for USB loopback test results
Sourcepub const fn utmo_dig_tst1(&self) -> bool
pub const fn utmo_dig_tst1(&self) -> bool
This read-only bit is a status bit for USB loopback test
Sourcepub const fn set_utmo_dig_tst1(&mut self, val: bool)
pub const fn set_utmo_dig_tst1(&mut self, val: bool)
This read-only bit is a status bit for USB loopback test
Sourcepub const fn tsti_hsfs_mode_en(&self) -> bool
pub const fn tsti_hsfs_mode_en(&self) -> bool
Setting this bit field to value 1’b1 will enable the loopback test to dynamically change the packet speed
Sourcepub const fn set_tsti_hsfs_mode_en(&mut self, val: bool)
pub const fn set_tsti_hsfs_mode_en(&mut self, val: bool)
Setting this bit field to value 1’b1 will enable the loopback test to dynamically change the packet speed
Sourcepub const fn tstpkt(&self) -> u8
pub const fn tstpkt(&self) -> u8
Selects the packet data byte used for USB loopback testing in Pulse mode
Sourcepub const fn set_tstpkt(&mut self, val: u8)
pub const fn set_tstpkt(&mut self, val: u8)
Selects the packet data byte used for USB loopback testing in Pulse mode