nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usb1VbusDetStat

Struct Usb1VbusDetStat 

#[repr(transparent)]
pub struct Usb1VbusDetStat(pub u32);
USB PHY VBUS Detector Status Register

Tuple Fields

0: u32

Implementations

Source

impl Usb1VbusDetStat

pub const fn sessend(&self) -> Sessend

Session End indicator Session End status, value inverted from Session Valid comparator

pub const fn set_sessend(&mut self, val: Sessend)

Session End indicator Session End status, value inverted from Session Valid comparator

pub const fn bvalid(&self) -> Bvalid

B-Device Session Valid status B-Device Session Valid status, determined by the Session Valid comparator

pub const fn set_bvalid(&mut self, val: Bvalid)

B-Device Session Valid status B-Device Session Valid status, determined by the Session Valid comparator

pub const fn avalid(&self) -> Avalid

A-Device Session Valid status A-Device Session Valid status, determined by the Session Valid comparator

pub const fn set_avalid(&mut self, val: Avalid)

A-Device Session Valid status A-Device Session Valid status, determined by the Session Valid comparator

pub const fn vbus_valid(&self) -> VbusValid

VBUS voltage status This bit field shows the result of VBUS_VALID detection for the USB1_VBUS pin

pub const fn set_vbus_valid(&mut self, val: VbusValid)

VBUS voltage status This bit field shows the result of VBUS_VALID detection for the USB1_VBUS pin

pub const fn vbus_valid_3v(&self) -> VbusValid3v

VBUS_VALID_3V detector status The VBUS_VALID_3V detector has a lower threshold for the voltage on the USB1_VBUS pin than either the Session Valid or VBUS_VALID comparators

pub const fn set_vbus_valid_3v(&mut self, val: VbusValid3v)

VBUS_VALID_3V detector status The VBUS_VALID_3V detector has a lower threshold for the voltage on the USB1_VBUS pin than either the Session Valid or VBUS_VALID comparators