nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usb1VbusDetect

Struct Usb1VbusDetect 

#[repr(transparent)]
pub struct Usb1VbusDetect(pub u32);
USB PHY VBUS Detect Control Register

Tuple Fields

0: u32

Implementations

Source

impl Usb1VbusDetect

pub const fn vbusvalid_thresh(&self) -> Usb1VbusDetectVbusvalidThresh

Sets the threshold for the VBUSVALID comparator

pub const fn set_vbusvalid_thresh(&mut self, val: Usb1VbusDetectVbusvalidThresh)

Sets the threshold for the VBUSVALID comparator

pub const fn vbus_override_en(&self) -> Usb1VbusDetectVbusOverrideEn

VBUS detect signal override enable

pub const fn set_vbus_override_en(&mut self, val: Usb1VbusDetectVbusOverrideEn)

VBUS detect signal override enable

pub const fn sessend_override(&self) -> bool

Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn set_sessend_override(&mut self, val: bool)

Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn bvalid_override(&self) -> bool

Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn set_bvalid_override(&mut self, val: bool)

Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn avalid_override(&self) -> bool

Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn set_avalid_override(&mut self, val: bool)

Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1

pub const fn vbusvalid_override(&self) -> bool

Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1

pub const fn set_vbusvalid_override(&mut self, val: bool)

Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1

pub const fn vbusvalid_sel(&self) -> Usb1VbusDetectVbusvalidSel

Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller

pub const fn set_vbusvalid_sel(&mut self, val: Usb1VbusDetectVbusvalidSel)

Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller

pub const fn vbus_source_sel(&self) -> Usb1VbusDetectVbusSourceSel

Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller

pub const fn set_vbus_source_sel(&mut self, val: Usb1VbusDetectVbusSourceSel)

Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller

pub const fn vbusvalid_to_sessvalid(&self) -> Usb1VbusDetectVbusvalidToSessvalid

Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator

pub const fn set_vbusvalid_to_sessvalid( &mut self, val: Usb1VbusDetectVbusvalidToSessvalid, )

Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator

pub const fn pwrup_cmps(&self) -> Usb1VbusDetectPwrupCmps

Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector

pub const fn set_pwrup_cmps(&mut self, val: Usb1VbusDetectPwrupCmps)

Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector

pub const fn discharge_vbus(&self) -> Usb1VbusDetectDischargeVbus

Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground

pub const fn set_discharge_vbus(&mut self, val: Usb1VbusDetectDischargeVbus)

Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground

pub const fn en_charger_resistor(&self) -> Usb1VbusDetectEnChargerResistor

Enables resistors used for an older method of resistive battery charger detection

pub const fn set_en_charger_resistor( &mut self, val: Usb1VbusDetectEnChargerResistor, )

Enables resistors used for an older method of resistive battery charger detection