#[repr(transparent)]pub struct Usb1VbusDetectClr(pub u32);Expand description
USB PHY VBUS Detect Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1VbusDetectClr
impl Usb1VbusDetectClr
Sourcepub const fn vbusvalid_thresh(&self) -> Usb1VbusDetectClrVbusvalidThresh
pub const fn vbusvalid_thresh(&self) -> Usb1VbusDetectClrVbusvalidThresh
Sets the threshold for the VBUSVALID comparator
Sourcepub const fn set_vbusvalid_thresh(
&mut self,
val: Usb1VbusDetectClrVbusvalidThresh,
)
pub const fn set_vbusvalid_thresh( &mut self, val: Usb1VbusDetectClrVbusvalidThresh, )
Sets the threshold for the VBUSVALID comparator
Sourcepub const fn vbus_override_en(&self) -> Usb1VbusDetectClrVbusOverrideEn
pub const fn vbus_override_en(&self) -> Usb1VbusDetectClrVbusOverrideEn
VBUS detect signal override enable
Sourcepub const fn set_vbus_override_en(
&mut self,
val: Usb1VbusDetectClrVbusOverrideEn,
)
pub const fn set_vbus_override_en( &mut self, val: Usb1VbusDetectClrVbusOverrideEn, )
VBUS detect signal override enable
Sourcepub const fn sessend_override(&self) -> bool
pub const fn sessend_override(&self) -> bool
Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_sessend_override(&mut self, val: bool)
pub const fn set_sessend_override(&mut self, val: bool)
Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn bvalid_override(&self) -> bool
pub const fn bvalid_override(&self) -> bool
Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_bvalid_override(&mut self, val: bool)
pub const fn set_bvalid_override(&mut self, val: bool)
Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn avalid_override(&self) -> bool
pub const fn avalid_override(&self) -> bool
Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_avalid_override(&mut self, val: bool)
pub const fn set_avalid_override(&mut self, val: bool)
Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn vbusvalid_override(&self) -> bool
pub const fn vbusvalid_override(&self) -> bool
Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1
Sourcepub const fn set_vbusvalid_override(&mut self, val: bool)
pub const fn set_vbusvalid_override(&mut self, val: bool)
Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1
Sourcepub const fn vbusvalid_sel(&self) -> Usb1VbusDetectClrVbusvalidSel
pub const fn vbusvalid_sel(&self) -> Usb1VbusDetectClrVbusvalidSel
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn set_vbusvalid_sel(&mut self, val: Usb1VbusDetectClrVbusvalidSel)
pub const fn set_vbusvalid_sel(&mut self, val: Usb1VbusDetectClrVbusvalidSel)
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn vbus_source_sel(&self) -> Usb1VbusDetectClrVbusSourceSel
pub const fn vbus_source_sel(&self) -> Usb1VbusDetectClrVbusSourceSel
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn set_vbus_source_sel(&mut self, val: Usb1VbusDetectClrVbusSourceSel)
pub const fn set_vbus_source_sel(&mut self, val: Usb1VbusDetectClrVbusSourceSel)
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn vbusvalid_to_sessvalid(
&self,
) -> Usb1VbusDetectClrVbusvalidToSessvalid
pub const fn vbusvalid_to_sessvalid( &self, ) -> Usb1VbusDetectClrVbusvalidToSessvalid
Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator
Sourcepub const fn set_vbusvalid_to_sessvalid(
&mut self,
val: Usb1VbusDetectClrVbusvalidToSessvalid,
)
pub const fn set_vbusvalid_to_sessvalid( &mut self, val: Usb1VbusDetectClrVbusvalidToSessvalid, )
Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator
Sourcepub const fn pwrup_cmps(&self) -> Usb1VbusDetectClrPwrupCmps
pub const fn pwrup_cmps(&self) -> Usb1VbusDetectClrPwrupCmps
Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector
Sourcepub const fn set_pwrup_cmps(&mut self, val: Usb1VbusDetectClrPwrupCmps)
pub const fn set_pwrup_cmps(&mut self, val: Usb1VbusDetectClrPwrupCmps)
Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector
Sourcepub const fn discharge_vbus(&self) -> Usb1VbusDetectClrDischargeVbus
pub const fn discharge_vbus(&self) -> Usb1VbusDetectClrDischargeVbus
Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground
Sourcepub const fn set_discharge_vbus(&mut self, val: Usb1VbusDetectClrDischargeVbus)
pub const fn set_discharge_vbus(&mut self, val: Usb1VbusDetectClrDischargeVbus)
Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground
Sourcepub const fn en_charger_resistor(&self) -> Usb1VbusDetectClrEnChargerResistor
pub const fn en_charger_resistor(&self) -> Usb1VbusDetectClrEnChargerResistor
Enables resistors used for an older method of resistive battery charger detection
Sourcepub const fn set_en_charger_resistor(
&mut self,
val: Usb1VbusDetectClrEnChargerResistor,
)
pub const fn set_en_charger_resistor( &mut self, val: Usb1VbusDetectClrEnChargerResistor, )
Enables resistors used for an older method of resistive battery charger detection