#[repr(transparent)]pub struct PwdClr(pub u32);Expand description
USB PHY Power-Down Register
Tuple Fields
0: u32Implementations
Sourceimpl PwdClr
impl PwdClr
Sourcepub const fn txpwdfs(&self) -> PwdClrTxpwdfs
pub const fn txpwdfs(&self) -> PwdClrTxpwdfs
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdfs(&mut self, val: PwdClrTxpwdfs)
pub const fn set_txpwdfs(&mut self, val: PwdClrTxpwdfs)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdibias(&self) -> PwdClrTxpwdibias
pub const fn txpwdibias(&self) -> PwdClrTxpwdibias
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdibias(&mut self, val: PwdClrTxpwdibias)
pub const fn set_txpwdibias(&mut self, val: PwdClrTxpwdibias)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdv2i(&self) -> PwdClrTxpwdv2i
pub const fn txpwdv2i(&self) -> PwdClrTxpwdv2i
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdv2i(&mut self, val: PwdClrTxpwdv2i)
pub const fn set_txpwdv2i(&mut self, val: PwdClrTxpwdv2i)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdenv(&self) -> PwdClrRxpwdenv
pub const fn rxpwdenv(&self) -> PwdClrRxpwdenv
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdenv(&mut self, val: PwdClrRxpwdenv)
pub const fn set_rxpwdenv(&mut self, val: PwdClrRxpwdenv)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwd1pt1(&self) -> PwdClrRxpwd1pt1
pub const fn rxpwd1pt1(&self) -> PwdClrRxpwd1pt1
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwd1pt1(&mut self, val: PwdClrRxpwd1pt1)
pub const fn set_rxpwd1pt1(&mut self, val: PwdClrRxpwd1pt1)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwddiff(&self) -> PwdClrRxpwddiff
pub const fn rxpwddiff(&self) -> PwdClrRxpwddiff
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwddiff(&mut self, val: PwdClrRxpwddiff)
pub const fn set_rxpwddiff(&mut self, val: PwdClrRxpwddiff)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdrx(&self) -> PwdClrRxpwdrx
pub const fn rxpwdrx(&self) -> PwdClrRxpwdrx
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdrx(&mut self, val: PwdClrRxpwdrx)
pub const fn set_rxpwdrx(&mut self, val: PwdClrRxpwdrx)
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled