#[repr(transparent)]pub struct PwdTog(pub u32);Expand description
USB PHY Power-Down Register
Tuple Fields
0: u32Implementations
Sourceimpl PwdTog
impl PwdTog
Sourcepub const fn txpwdfs(&self) -> PwdTogTxpwdfs
pub const fn txpwdfs(&self) -> PwdTogTxpwdfs
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdfs(&mut self, val: PwdTogTxpwdfs)
pub const fn set_txpwdfs(&mut self, val: PwdTogTxpwdfs)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdibias(&self) -> PwdTogTxpwdibias
pub const fn txpwdibias(&self) -> PwdTogTxpwdibias
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdibias(&mut self, val: PwdTogTxpwdibias)
pub const fn set_txpwdibias(&mut self, val: PwdTogTxpwdibias)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn txpwdv2i(&self) -> PwdTogTxpwdv2i
pub const fn txpwdv2i(&self) -> PwdTogTxpwdv2i
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_txpwdv2i(&mut self, val: PwdTogTxpwdv2i)
pub const fn set_txpwdv2i(&mut self, val: PwdTogTxpwdv2i)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdenv(&self) -> PwdTogRxpwdenv
pub const fn rxpwdenv(&self) -> PwdTogRxpwdenv
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdenv(&mut self, val: PwdTogRxpwdenv)
pub const fn set_rxpwdenv(&mut self, val: PwdTogRxpwdenv)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwd1pt1(&self) -> PwdTogRxpwd1pt1
pub const fn rxpwd1pt1(&self) -> PwdTogRxpwd1pt1
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwd1pt1(&mut self, val: PwdTogRxpwd1pt1)
pub const fn set_rxpwd1pt1(&mut self, val: PwdTogRxpwd1pt1)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwddiff(&self) -> PwdTogRxpwddiff
pub const fn rxpwddiff(&self) -> PwdTogRxpwddiff
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwddiff(&mut self, val: PwdTogRxpwddiff)
pub const fn set_rxpwddiff(&mut self, val: PwdTogRxpwddiff)
Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn rxpwdrx(&self) -> PwdTogRxpwdrx
pub const fn rxpwdrx(&self) -> PwdTogRxpwdrx
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled
Sourcepub const fn set_rxpwdrx(&mut self, val: PwdTogRxpwdrx)
pub const fn set_rxpwdrx(&mut self, val: PwdTogRxpwdrx)
This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled