#[repr(transparent)]pub struct Usb1ChrgDetStat(pub u32);Expand description
USB PHY Charger Detect Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1ChrgDetStat
impl Usb1ChrgDetStat
Sourcepub const fn plug_contact(&self) -> PlugContact
pub const fn plug_contact(&self) -> PlugContact
Battery Charging Data Contact Detection phase output During the Data Contact Detection phase per the USB Battery Charging Specification Revision 1
Sourcepub const fn set_plug_contact(&mut self, val: PlugContact)
pub const fn set_plug_contact(&mut self, val: PlugContact)
Battery Charging Data Contact Detection phase output During the Data Contact Detection phase per the USB Battery Charging Specification Revision 1
Sourcepub const fn chrg_detected(&self) -> ChrgDetected
pub const fn chrg_detected(&self) -> ChrgDetected
Battery Charging Primary Detection phase output During the USB Battery Charging Primary Detection phase using the USBHSDCD module, this bit field indicates whether a Standard Downstream Port or Charging Port was detected
Sourcepub const fn set_chrg_detected(&mut self, val: ChrgDetected)
pub const fn set_chrg_detected(&mut self, val: ChrgDetected)
Battery Charging Primary Detection phase output During the USB Battery Charging Primary Detection phase using the USBHSDCD module, this bit field indicates whether a Standard Downstream Port or Charging Port was detected
Sourcepub const fn dm_state(&self) -> DmState
pub const fn dm_state(&self) -> DmState
Single ended receiver output for the USB_DM pin, from charger detection circuits.
Sourcepub const fn set_dm_state(&mut self, val: DmState)
pub const fn set_dm_state(&mut self, val: DmState)
Single ended receiver output for the USB_DM pin, from charger detection circuits.
Sourcepub const fn dp_state(&self) -> DpState
pub const fn dp_state(&self) -> DpState
Single ended receiver output for the USB_DP pin, from charger detection circuits.
Sourcepub const fn set_dp_state(&mut self, val: DpState)
pub const fn set_dp_state(&mut self, val: DpState)
Single ended receiver output for the USB_DP pin, from charger detection circuits.
Sourcepub const fn secdet_dcp(&self) -> SecdetDcp
pub const fn secdet_dcp(&self) -> SecdetDcp
Battery Charging Secondary Detection phase output During the USB Battery Charging Secondary Detection phase using the USBHSDCD module, this bit field indicates which kind of Charging Port was detected
Sourcepub const fn set_secdet_dcp(&mut self, val: SecdetDcp)
pub const fn set_secdet_dcp(&mut self, val: SecdetDcp)
Battery Charging Secondary Detection phase output During the USB Battery Charging Secondary Detection phase using the USBHSDCD module, this bit field indicates which kind of Charging Port was detected