#[repr(transparent)]pub struct Usb1VbusDetStat(pub u32);Expand description
USB PHY VBUS Detector Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1VbusDetStat
impl Usb1VbusDetStat
Sourcepub const fn sessend(&self) -> Sessend
pub const fn sessend(&self) -> Sessend
Session End indicator Session End status, value inverted from Session Valid comparator
Sourcepub const fn set_sessend(&mut self, val: Sessend)
pub const fn set_sessend(&mut self, val: Sessend)
Session End indicator Session End status, value inverted from Session Valid comparator
Sourcepub const fn bvalid(&self) -> Bvalid
pub const fn bvalid(&self) -> Bvalid
B-Device Session Valid status B-Device Session Valid status, determined by the Session Valid comparator
Sourcepub const fn set_bvalid(&mut self, val: Bvalid)
pub const fn set_bvalid(&mut self, val: Bvalid)
B-Device Session Valid status B-Device Session Valid status, determined by the Session Valid comparator
Sourcepub const fn avalid(&self) -> Avalid
pub const fn avalid(&self) -> Avalid
A-Device Session Valid status A-Device Session Valid status, determined by the Session Valid comparator
Sourcepub const fn set_avalid(&mut self, val: Avalid)
pub const fn set_avalid(&mut self, val: Avalid)
A-Device Session Valid status A-Device Session Valid status, determined by the Session Valid comparator
Sourcepub const fn vbus_valid(&self) -> VbusValid
pub const fn vbus_valid(&self) -> VbusValid
VBUS voltage status This bit field shows the result of VBUS_VALID detection for the USB1_VBUS pin
Sourcepub const fn set_vbus_valid(&mut self, val: VbusValid)
pub const fn set_vbus_valid(&mut self, val: VbusValid)
VBUS voltage status This bit field shows the result of VBUS_VALID detection for the USB1_VBUS pin
Sourcepub const fn vbus_valid_3v(&self) -> VbusValid3v
pub const fn vbus_valid_3v(&self) -> VbusValid3v
VBUS_VALID_3V detector status The VBUS_VALID_3V detector has a lower threshold for the voltage on the USB1_VBUS pin than either the Session Valid or VBUS_VALID comparators
Sourcepub const fn set_vbus_valid_3v(&mut self, val: VbusValid3v)
pub const fn set_vbus_valid_3v(&mut self, val: VbusValid3v)
VBUS_VALID_3V detector status The VBUS_VALID_3V detector has a lower threshold for the voltage on the USB1_VBUS pin than either the Session Valid or VBUS_VALID comparators